################
Using django CMS
################

.. note::

          This is a new section in the django CMS documentation, and a priority
          for the project. If you'd like to contribute to it, we'd love to hear
          from you - join us on `our friendly Slack group
          <https://www.django-cms.org/slack>`_.


The **Using django CMS** documentation is divided into two parts.

First, there's a :ref:`tutorial <user-tutorial>` that takes you step-by-step
through key processes. Once you've completed this you will be familiar with the
basics of content editing using the system.

The tutorial contains numerous links to items in the :ref:`reference section
<user-reference>`.

The documentation in these two sections focuses on the basics of content
creation and editing using django CMS's powerful front-end editing mode. It's
suitable for non-technical and technical audiences alike.

However, it can only cover the basics that are common to most sites built using
django CMS. Your own site will likely have many custom changes and special
purpose plugins which we cannot cover here. Nevertheless, by the end of this
guide you should be comfortable with the content editing process using django
CMS. Many of the skills you'll learn will be transferable to any custom plugins
your site may have.

.. toctree::
    :maxdepth: 2

    tutorial/index
    reference/index


.. _django-cms-developers: https://groups.google.com/group/django-cms-developers
